==> haskell-blaze-textual-0.2.2.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-textual
version:              0.2.2.1
visibility:           public
id:                   blaze-textual-0.2.2.1-E7IOoy4Sbug3er2PeCwnRj
key:                  blaze-textual-0.2.2.1-E7IOoy4Sbug3er2PeCwnRj
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>
    , Andrey Prokopenko <persiantiger@yandex.ru>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/bos/blaze-textual#readme>

category:             Text
abi:                  fef61785c9bfa956de1fb8aa9a0b0810
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.0.2/site-local/blaze-textual-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/blaze-textual-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.2.1-E7IOoy4Sbug3er2PeCwnRj
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    bytestring-0.10.12.1 ghc-prim-0.7.0 integer-gmp-1.1
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh text-1.2.5.0 time-1.9.3
    vector-0.12.3.1-50x5zOQFZ1CIL15Y9vpvyM

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-textual-0.2.2.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-textual
version:              0.2.2.1
visibility:           public
id:                   blaze-textual-0.2.2.1-Kd6j3GgqPvh1k8fmwFoDlx
key:                  blaze-textual-0.2.2.1-Kd6j3GgqPvh1k8fmwFoDlx
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>
    , Andrey Prokopenko <persiantiger@yandex.ru>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             http://github.com/bos/blaze-textual
synopsis:             Fast rendering of common datatypes
description:
    A library for efficiently rendering Haskell datatypes to
    bytestrings.

    /Note/: if you use GHCi or Template Haskell, please see the
    @README@ file for important details about building this package,
    and other packages that depend on it:
    <https://github.com/bos/blaze-textual#readme>

category:             Text
abi:                  ed8c5fa435a3fc842cf3bfe15c482025
exposed:              True
exposed-modules:      Blaze.Text Blaze.Text.Double Blaze.Text.Int
hidden-modules:       Blaze.Text.Double.Native
import-dirs:          /usr/lib/ghc-9.0.2/site-local/blaze-textual-0.2.2.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/blaze-textual-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-textual
hs-libraries:         HSblaze-textual-0.2.2.1-Kd6j3GgqPvh1k8fmwFoDlx
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    bytestring-0.10.12.1 ghc-prim-0.7.0 integer-gmp-1.1
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh text-1.2.5.0 time-1.9.3
    vector-0.12.3.1-8Paq2PiUkmTCuMydFwPkkl

haddock-interfaces:
    /usr/share/doc/haskell-blaze-textual/html/blaze-textual.haddock

haddock-html:         /usr/share/doc/haskell-blaze-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
